# jotterepo
 RAM my favourite type of pizza. Do you know how good pizza is on RAM? Now, you might be asking me; “Why did you say pizza is good on ram?” I’ll tell you, pizza is only a topping compared to RAM. That’s how good it is. Stop. I’ll tell you your next move. You’re going to ignore me for the rest of your life, but hear me out. Have you ever tried pizza on RAM? You never know until you try it. There are also other types of absolutely awesome pizza, like pizza on GPU or pizza on CPU. Here, I’ll order a pizza on RAM for you. Don’t stop me, if you don’t like it it’s fine. I’ll just eat the rest. I don’t really care much about money anyway, so here goes. (text in quotation is the person at the other end of the line speaking) * ring ring * “Hi, welcome to Nikz’ Pizza, what may I get you today?” I’d like to order a pizza on RAM? Do you have that in stock? “No, I’m sorry. It’s been sold out.” Alright, thanks for your service. * hangs up * Well, there goes that. I’ll remember to order you a pizza on ram next time they’re in stock. Just remind me to do it. Anyway, gotta go, still have a bunch of pizza left at my place that I’ve been storing. See ya!
